@@ -16,6 +16,8 @@ import os
 from os import listdir, makedirs
 from os.path import dirname
 import requests
+import datetime
+
 
 class ZephyrFormatter(Formatter):
     name = "Zepher Formatter"
@@ -28,7 +30,10 @@ class ZephyrFormatter(Formatter):
     json_scalar_types = json_number_types + (six.text_type, bool, type(None))
     file = None
     step_count = 0
-    
+    api_key = None
+    test_cycle_key = None
+    start_date_time = datetime.datetime.now().strftime("%Y-%m-%dT%H:%M:%S.000+0000")
+    url_base = None
 
     def __init__(self, stream_opener, config):
         super(ZephyrFormatter, self).__init__(stream_opener, config)
@@ -40,8 +45,14 @@ class ZephyrFormatter(Formatter):
         self.current_scenario = None
         self._step_index = 0
         self.step_count = 0
-        self.str_result_json=""
+        self.str_result_json = ""
 
+        api_key = self.config.userdata.get("ZEPHYR_API_KEY", None)
+        if not api_key:  # I know... this is unfortuantely a hack for a short comming
+            api_key = self.config.userdata.get("zephyr_api_key", "")
+
+        self.api_key = api_key
+        self.url_base = self.config.userdata.get("ZEPHYR_API_URL", "")
 
     def reset(self):
         self.current_feature = None
@@ -211,7 +222,6 @@ class ZephyrFormatter(Formatter):
 
     def open_new_file(self):
         self.file = open(f"{self.results_dir}/tmp.json", "w")
-        
 
     def close(self):
         if self.feature_count == 0:
@@ -219,7 +229,11 @@ class ZephyrFormatter(Formatter):
             self.write_json_header()
 
         self.zip_files()
-        self.upload_results()
+        if self.api_key:
+            self.upload_results()
+            self.update_testCycle()
+        else:
+            print("No ZEPHYR_API_KEY provided.  No updates send to Zepker")
         self.file_cleanup()
 
     # -- JSON-DATA COLLECTION:
@@ -265,22 +279,22 @@ class ZephyrFormatter(Formatter):
     # -- File functions:
     def create_results_dirs(self):
         # path = dirname(dirname(__file__))
-        dirs = self.results_dir.split('/')
+        dirs = self.results_dir.split("/")
         path = ""
         for dir_name in dirs:
             try:
                 # Create target Directory
-                if path == "" :
+                if path == "":
                     path = dir_name
                     makedirs(dir_name)
                 else:
                     path = f"{path}/{dir_name}"
                     makedirs(path)
-                print("Directory " , path ,  " Created ") 
-                
+                print("Directory ", path, " Created ")
+
             except FileExistsError:
                 if self.config.verbose:
-                    print("Directory " , path ,  " already exists")        
+                    print("Directory ", path, " already exists")
                 pass
 
     def file_cleanup(self, all_files=False, name=""):
@@ -300,7 +314,6 @@ class ZephyrFormatter(Formatter):
                     print("Can not delete folder")
                 pass
 
-
     def zip_files(self):
         if len(os.listdir(self.results_dir)) > 1:  # There will be a tmp.json file
 
@@ -337,31 +350,49 @@ class ZephyrFormatter(Formatter):
             f.write(json.dumps(zephyr_json))
 
     def upload_results(self):
-        upload_results = self.config.userdata.get("ZEPHYR_UPLOAD_RESULTS", 'false').lower()
-        
-        if upload_results == 'false':
+        upload_results = self.config.userdata.get(
+            "ZEPHYR_UPLOAD_RESULTS", "false"
+        ).lower()
+
+        if upload_results == "false":
             return
 
-        url_base = self.config.userdata.get("ZEPHYR_API_URL", "")
         zephyr_project_key = self.config.userdata.get("ZEPHYR_PROJECT_KEY", "")
-        api_key = self.config.userdata.get("ZEPHYR_API_KEY", "")
-        if api_key == "": # I know... this is unfortuantely a hack for a short comming
-            api_key = self.config.userdata.get("zephyr_api_key", "")
 
-        create_test_cases = self.config.userdata.get("ZEPHYR_AUTO_CREATE_TEST_CASES", 'false').lower()
-        url = f"{url_base}?projectKey={zephyr_project_key}&autoCreateTestCases={create_test_cases}"
+        create_test_cases = self.config.userdata.get(
+            "ZEPHYR_AUTO_CREATE_TEST_CASES", "false"
+        ).lower()
+        url = f"{self.url_base}/v2/automations/executions/cucumber?projectKey={zephyr_project_key}&autoCreateTestCases={create_test_cases}"
 
         file = f"{self.results_dir}/{self.results_file}"
 
-        payload={}
-        files=[('file',(self.results_file,open(file,'rb'),'application/zip'))]
-        headers = {
-            'Authorization': api_key
-        }
+        payload = {}
+        files = [("file", (self.results_file, open(file, "rb"), "application/zip"))]
+        headers = {"Authorization": self.api_key}
 
-        response = requests.request("POST", url, headers=headers, data=payload, files=files)
+        response = requests.request(
+            "POST", url, headers=headers, data=payload, files=files
+        )
         response.raise_for_status()
-        print(f"Test cycle key: {json.loads(response.text)['testCycle']['key']}")
+        print(f"Test cycle key: {response.json()['testCycle']['key']}")
+        self.test_cycle_key = response.json()["testCycle"]["key"]
 
+    def update_testCycle(self):
+        # Get test cycle data from Zepyr
+        url = f"{self.url_base}/v2/testcycles/{self.test_cycle_key}"
+        headers = {"Authorization": self.api_key, "Content-Type": "application/json"}
+        response = requests.request("GET", url, headers=headers)
+        response.raise_for_status()
 
+        # Add detail to response before posting it back to Zephyr
+        data = response.json()
+        test_name = self.config.userdata.get(
+            "ZEPHYR_TEST_CYCLE_NAME",
+            f"Automation Build {datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')}",
+        )
+        data["name"] = test_name
+        data["plannedStartDate"] = self.start_date_time
+        data["plannedEndDate"] = datetime.datetime.now().strftime("%Y-%m-%dT%H:%M:%S.000+0000")
 
+        response = requests.request("PUT", url, headers=headers, data=json.dumps(data))
+        response.raise_for_status()
